import * as React from 'react';
import { useState, useEffect } from 'react';
import { connect, useDispatch, useSelector } from 'react-redux';
import { useHistory, useParams } from "react-router-dom";
import { store } from '../../redux';

import Box from '@mui/material/Box';
import TextField from '@mui/material/TextField';
import Stack from '@mui/material/Stack';
// import Button from '@mui/material/Button';
import Container from '@mui/material/Container';
import SendRoundedIcon from '@mui/icons-material/SendRounded';
import Button from '@mui/material-next/Button';

import { StyledDropzone } from './dropzone';
import { actionFilesUpload, actionFullCreatePost } from '../../redux/thunks';
import { actionCreatePost } from '../../redux/action';
import HighlightOffRoundedIcon from '@mui/icons-material/HighlightOffRounded';
import { Dnd } from './dnd';
import { UploadedFiles } from './uploaded_files';
import { actionFindPostOne } from '../../redux/action';


export const CreatePost = () => {

    // отслеживаем url поста. если create - создаем новый
    const { postId } = useParams()
    // console.log('params', postId)

    // редактирование поста
    useEffect(() => {
        if (postId !== 'create') {
            const getPost = async (id) => {
                const res = await dispatch(actionFindPostOne(id))
                console.log('res', res)

                if (res) {
                    post._id = postId
                    setPost({
                        ...post,
                        images: [...post.images, ...(res?.images || [])],
                        title: res?.title,
                        text: res?.text
                    })
                }
            }
            getPost(postId)
        }
    }, [postId])


    // параметры для поста
    const [post, setPost] = useState({ title: '', text: '', images: [] })
    console.log('post', post)

    // создаем объект с данными из форм для отправки на бек
    const newPostData = ({ ...post, images: ((post.images)?.map(item => ({ _id: item._id }))) })
    console.log('newPostData', newPostData)

    const dispatch = useDispatch()

    // вот эту часть нужно будет сделать через connect???
    const images = useSelector(state => state.promise?.FilesUpload?.payload)

    useEffect((() => {
        if (images) {
            setPost({ ...post, images: [...post.images, ...images] })
        }
    }), [images])


    const deleteImage = image => setPost({ ...post, images: post.images.filter(i => i !== image) })

    const localPostImage = ({ image }) => <UploadedFiles image={image}
        onDelete={imgToDelete => deleteImage(imgToDelete)} />


    // создаем новый пост и переходим на его страницу
    const history = useHistory()

    const newPost = useSelector(state => state.promise?.CreatePost?.payload?._id)
    // console.log('newPost', newPost)


    async function onSend() {
        const res = await dispatch(actionFullCreatePost(newPostData));

        if (res) {
            history.push(`/post/${res?._id}`);
        }
    }


    return (
        <Container maxWidth="90%">
            <Container>
                <StyledDropzone onFiles={files => dispatch(actionFilesUpload(files))} onPost={post} />
            </Container>


            <Dnd items={post.images} render={localPostImage} itemProp="image" keyField="_id"
                onChange={images => setPost({ ...post, images })}
                horizontal
            />

            <Box
                component="form"
                sx={{
                    '& > :not(style)': { m: 1, width: '100%', marginBottom: '20px' },
                }}
            >
                <TextField
                    id="title"
                    label="Название поста"
                    variant="standard"
                    onChange={e => setPost({ ...post, title: e.target.value })}
                    value={post.title}
                />
            </Box>

            <Box
                component="form"
                sx={{
                    '& .MuiTextField-root': { m: 1, width: '100%', marginBottom: '20px' },
                }}
            >
                <TextField
                    id="text"
                    label="Описание поста"
                    multiline
                    variant="standard"
                    onChange={e => setPost({ ...post, text: e.target.value })}
                    value={post.text}
                />
            </Box>

            {/* <Container spacing={2} direction="row" > */}
            {/* <Button
                    variant="outlined"
                    startIcon={
                        <SendRoundedIcon
                            style={{ transform: 'translate(3px, -4px) rotate(-30deg)' }}
                        />}

                    onClick={onSend}
                >
                    Опубликовать пост
                </Button> */}


            <Container
                onClick={onSend}
                sx={{
                    display: 'flex',
                    justifyContent: 'center'
                }}
            >
                <Button
                    size="medium"
                    variant="filledTonal"
                    startIcon={
                        <SendRoundedIcon
                            style={{ transform: 'translate(3px, -4px) rotate(-30deg)' }}
                        />}
                >
                    Опубликовать пост
                </Button>
            </Container>

            {/* </Container > */}
        </Container >
    )
}
